==> ogre-13.4.1.tar.gz: ogre-13.4.1/OgreMain/src/OgrePVRTCCodec.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#ifndef __OgrePVRTCCodec_H__
#define __OgrePVRTCCodec_H__

#include "OgreImageCodec.h"

namespace Ogre {
	/** \addtogroup Core
	*  @{
	*/
	/** \addtogroup Image
	*  @{
	*/

    /** Codec specialized in loading PVRTC (PowerVR) images.

		We implement our own codec here since we need to be able to keep PVRTC
		data compressed if the card supports it.
    */
    class PVRTCCodec : public ImageCodec
    {
    private:
        String mType;

		/// Single registered codec instance
		static PVRTCCodec* msInstance;

	public:
        PVRTCCodec();
        virtual ~PVRTCCodec() { }

        using ImageCodec::decode;
        DecodeResult decode(const DataStreamPtr& input) const override;
		String magicNumberToFileExt(const char *magicNumberPtr, size_t maxbytes) const override;
        String getType() const override;

		/// Static method to startup and register the PVRTC codec
		static void startup(void);
		/// Static method to shutdown and unregister the PVRTC codec
		static void shutdown(void);

	private:
		/// Decode PVRTCV2 image format
		DecodeResult decodeV2(const DataStreamPtr& stream) const;

		/// Decode PVRTCV3 image format
		DecodeResult decodeV3(const DataStreamPtr& stream) const;
    };
	/** @} */
	/** @} */

} // namespace

#endif

==> ogre_14.3.1.orig.tar.gz: ogre-14.3.1/OgreMain/src/OgrePVRTCCodec.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#ifndef __OgrePVRTCCodec_H__
#define __OgrePVRTCCodec_H__

#include "OgreImageCodec.h"

namespace Ogre {
	/** \addtogroup Core
	*  @{
	*/
	/** \addtogroup Image
	*  @{
	*/

    /** Codec specialized in loading PVRTC (PowerVR) images.

		We implement our own codec here since we need to be able to keep PVRTC
		data compressed if the card supports it.
    */
    class PVRTCCodec : public ImageCodec
    {
    private:
        String mType;

		/// Single registered codec instance
		static PVRTCCodec* msInstance;

	public:
        PVRTCCodec();
        virtual ~PVRTCCodec() { }

        void decode(const DataStreamPtr& input, const Any& output) const override;
		String magicNumberToFileExt(const char *magicNumberPtr, size_t maxbytes) const override;
        String getType() const override;

		/// Static method to startup and register the PVRTC codec
		static void startup(void);
		/// Static method to shutdown and unregister the PVRTC codec
		static void shutdown(void);

	private:
		/// Decode PVRTCV2 image format
		static void decodeV2(const DataStreamPtr& stream, Image* image);

		/// Decode PVRTCV3 image format
		static void decodeV3(const DataStreamPtr& stream, Image* image);
    };
	/** @} */
	/** @} */

} // namespace

#endif
